package WebGUI::i18n::Spanish::Asset_Photo;
use utf8;
our $I18N = {
  'assetName' => {
    'lastUpdated' => '1207257485',
    'message' => 'Foto'
  },
  'comment message' => {
    'lastUpdated' => '1224515305',
    'message' => 'Su comentario fue agregado. <a href="%s">Regresar a la Foto.</a>'
  },
  'commentForm error no bodyText' => {
    'lastUpdated' => '1224515367',
    'message' => 'Para poder crear un comentario es necesario escribir algo.'
  },
  'commentForm error no commentId' => {
    'lastUpdated' => '1224515495',
    'message' => 'No se encontr&oacute; ID para comentarios. Esto indica un problema con la plantilla de presentaci&oacute;n de comentarios. Por favor notifique el problema al administrador.'
  },
  'delete message' => {
    'lastUpdated' => '1224515526',
    'message' => 'La foto ha sido borrada. <a href="%s">Regresar al Album.</a>'
  },
  'editCommentSave message' => {
    'lastUpdated' => '1224515541',
    'message' => 'El comentario ha sido actualizado. <a href="%s">Volver a la Foto.</a>'
  },
  'editForm cancel' => {
    'lastUpdated' => '1215795706',
    'message' => 'Cancelar'
  },
  'editForm friendsOnly' => {
    'lastUpdated' => '1215795737',
    'message' => 'Amigos Solamente'
  },
  'editForm keywords' => {
    'lastUpdated' => '1215796235',
    'message' => 'Etiquetas'
  },
  'editForm location' => {
    'lastUpdated' => '1252548988',
    'message' => 'Ubicación'
  },
  'editForm photo new' => {
    'lastUpdated' => '1215795794',
    'message' => 'Nueva Foto'
  },
  'editForm photo replace' => {
    'lastUpdated' => '1215795812',
    'message' => 'Reemplazar Foto'
  },
  'editForm save' => {
    'lastUpdated' => '1215795835',
    'message' => 'Guardar'
  },
  'editForm synopsis label' => {
    'lastUpdated' => '1224515645',
    'message' => 'Leyenda'
  },
  'editForm title label' => {
    'lastUpdated' => '1215795960',
    'message' => 'T&iacute;tulo'
  },
  'error no image' => {
    'lastUpdated' => '1276810368',
    'message' => 'Debe seleccionar una imagen a subir.'
  },
  'error no space' => {
    'lastUpdated' => '1224515700',
    'message' => 'Usted no dispone de espacio en disco suficiente para incorporar la Foto.'
  },
  'form comment save comment' => {
    'lastUpdated' => '1252549000',
    'message' => 'Guardar comentario.'
  },
  'help commentForm body' => {
    'lastUpdated' => '1215796053',
    'message' => 'Estas variables de plantilla componen el formulario para que los usuarios puedan enviar comentarios sobre Fotos'
  },
  'help commentForm title' => {
    'lastUpdated' => '1215796090',
    'message' => 'Foto-- Formulario de comentarios'
  },
  'help common body' => {
    'lastUpdated' => '1224515745',
    'message' => 'Estas Variables para Plantillas son comunes a todos los modos de presentaci&oacute;n de los Activos Foto.'
  },
  'help common title' => {
    'lastUpdated' => '1224515764',
    'message' => 'Foto -- Comunes'
  },
  'help delete body' => {
    'lastUpdated' => '1224515788',
    'message' => 'Confirme la eliminaci&oacute;n de un Activo Foto.'
  },
  'help delete title' => {
    'lastUpdated' => '1224515813',
    'message' => 'Foto -- Eliminar'
  },
  'help edit body' => {
    'lastUpdated' => '1224515846',
    'message' => 'Estas Variables para Plantillas permiten agregar o editar Activos Foto.'
  },
  'help edit title' => {
    'lastUpdated' => '1224515860',
    'message' => 'Foto -- Editar'
  },
  'help editComment body' => {
    'lastUpdated' => '1224515889',
    'message' => 'Estas Variables de Plantilla est&aacute;n disponibles en la p&aacute;gina de Editar Comentarios sobre Activos Foto.'
  },
  'help editComment title' => {
    'lastUpdated' => '1224515913',
    'message' => 'Plantilla para Editar Comentarios sobre Fotos'
  },
  'help makeShortcut body' => {
    'lastUpdated' => '1224515949',
    'message' => 'Estas Variables para Plantillas permiten crear enlaces hacia Activos Foto.'
  },
  'help makeShortcut title' => {
    'lastUpdated' => '1252549031',
    'message' => 'Foto -- Formulario para crear Atajo'
  },
  'help view body' => {
    'lastUpdated' => '1252549057',
    'message' => 'Estas variables de Plantilla aplican a las páginas para mostrar Fotos.'
  },
  'help view title' => {
    'lastUpdated' => '1215796529',
    'message' => 'Foto -- Vista Normal'
  },
  'helpvar album_menuTitle' => {
    'lastUpdated' => '1252549221',
    'message' => 'El Título de menú del Album que contiene este Archivo.'
  },
  'helpvar album_thumbnailUrl' => {
    'lastUpdated' => '1252549264',
    'message' => 'El URL de la miniatura del Album que contiene este Archivo.'
  },
  'helpvar album_title' => {
    'lastUpdated' => '1252549298',
    'message' => 'El Título del Album que contiene este Archivo.'
  },
  'helpvar album_url' => {
    'lastUpdated' => '1252549313',
    'message' => 'El URL del Album que contiene este Archivo.'
  },
  'helpvar canComment' => {
    'lastUpdated' => '1252549344',
    'message' => 'Un condicional que indica si el usuario actual puede comentar la Foto o no.'
  },
  'helpvar canEdit' => {
    'lastUpdated' => '1252549360',
    'message' => 'Un condicional que indica si el usuario actual puede editar esta Foto o no.'
  },
  'helpvar commentForm_bodyText' => {
    'lastUpdated' => '1252549446',
    'message' => 'El cuerpo del comentario, editable con el Editor Extendido configurado en la Galería que contiene la Foto.'
  },
  'helpvar commentForm_end' => {
    'lastUpdated' => '1252549470',
    'message' => 'Fin del formulario para comentarios.'
  },
  'helpvar commentForm_start' => {
    'lastUpdated' => '1252549498',
    'message' => 'Inicio del formulario para comentarios.'
  },
  'helpvar commentForm_submit' => {
    'lastUpdated' => '1252549518',
    'message' => 'Enviar el formulario de comentarios.'
  },
  'helpvar commentLoop' => {
    'lastUpdated' => '1252549547',
    'message' => 'Un ciclo que itera sobre los comentarios hechos sobre la Foto.'
  },
  'helpvar commentLoop bodyText' => {
    'lastUpdated' => '1252549582',
    'message' => 'El cuerpo del comentario.'
  },
  'helpvar commentLoop creationDate' => {
    'lastUpdated' => '1252549604',
    'message' => 'La fecha de creación del comentario.'
  },
  'helpvar commentLoop url_deleteComment' => {
    'lastUpdated' => '1252549631',
    'message' => 'El URL para eliminar este comentario.'
  },
  'helpvar commentLoop userId' => {
    'lastUpdated' => '1252549649',
    'message' => 'El <strong>userId</strong> del usuario que hizo el comentario.'
  },
  'helpvar commentLoop username' => {
    'lastUpdated' => '1252549661',
    'message' => 'El nombre de usuario del usuario que hizo el comentario.'
  },
  'helpvar commentLoop visitorIp' => {
    'lastUpdated' => '1252549686',
    'message' => 'Si el usuario es visitante, la dirección IP del usuario.'
  },
  'helpvar commentLoop_pageBar' => {
    'lastUpdated' => '1252549725',
    'message' => 'La barra para navegar a través de las páginas de comentarios.'
  },
  'helpvar error' => {
    'lastUpdated' => '1252549768',
    'message' => 'El mensaje de error traducido.'
  },
  'helpvar errors' => {
    'lastUpdated' => '1252549792',
    'message' => 'Un ciclo que itera sobre los mensajes de error para mostrar al usuario'
  },
  'helpvar exifLoop' => {
    'lastUpdated' => '1252549836',
    'message' => 'Un ciclo que itera sobre las etiquetas EXIF de la Foto.'
  },
  'helpvar exifLoop tag' => {
    'lastUpdated' => '1252549849',
    'message' => 'El nombre de la etiqueta EXIF de la Foto.'
  },
  'helpvar exifLoop value' => {
    'lastUpdated' => '1252549861',
    'message' => 'El valor de la etiqueta EXIF de la Foto.'
  },
  'helpvar exif_' => {
    'lastUpdated' => '1252549879',
    'message' => 'Cada etiqueta EXIF puede ser referida por nombre con el prefjio exif_.'
  },
  'helpvar fileUrl' => {
    'lastUpdated' => '1252549989',
    'message' => 'El URL a la Foto en tamaño normal.'
  },
  'helpvar firstFile_thumbnailUrl' => {
    'lastUpdated' => '1272375863',
    'message' => 'El URL de la imagen miniatura para la primera imagen del Album.'
  },
  'helpvar firstFile_title' => {
    'lastUpdated' => '1272375873',
    'message' => 'El título de la primera imagen del Album.'
  },
  'helpvar firstFile_url' => {
    'lastUpdated' => '1272375885',
    'message' => 'El URL de la primera imagen del Album.'
  },
  'helpvar form_end' => {
    'lastUpdated' => '1252550000',
    'message' => 'Fin del formulario.'
  },
  'helpvar form_friendsOnly' => {
    'lastUpdated' => '1252550182',
    'message' => '¿Sólo los amigos pueden ver esta foto?'
  },
  'helpvar form_keywords' => {
    'lastUpdated' => '1252550194',
    'message' => 'Las palabras claves para la Foto.'
  },
  'helpvar form_location' => {
    'lastUpdated' => '1252550275',
    'message' => 'La ubicación en la cual se tomó la Foto.'
  },
  'helpvar form_parentId' => {
    'lastUpdated' => '1252550389',
    'message' => 'Seleccionar el Album hacia el cual hacer el atajo.'
  },
  'helpvar form_photo' => {
    'lastUpdated' => '1252550527',
    'message' => 'La Foto a incorporar.'
  },
  'helpvar form_start' => {
    'lastUpdated' => '1252550544',
    'message' => 'Inicio del formulario.'
  },
  'helpvar form_submit' => {
    'lastUpdated' => '1252550558',
    'message' => 'Enviar el formulario.'
  },
  'helpvar form_synopsis' => {
    'lastUpdated' => '1252550587',
    'message' => 'La leyenda para la Foto.'
  },
  'helpvar form_title' => {
    'lastUpdated' => '1252550601',
    'message' => 'El Título de la Foto.'
  },
  'helpvar gallery_menuTitle' => {
    'lastUpdated' => '1252550617',
    'message' => 'El Título de menú de la Galería que contiene esta Foto.'
  },
  'helpvar gallery_title' => {
    'lastUpdated' => '1252550640',
    'message' => 'El Título de la Galería que contiene esta Foto.'
  },
  'helpvar gallery_url' => {
    'lastUpdated' => '1252550656',
    'message' => 'El URL de la Galería que contiene esta Foto.'
  },
  'helpvar isNewPhoto' => {
    'lastUpdated' => '1252550694',
    'message' => 'Un condicional que indica si el usuario esta agregando una Foto.'
  },
  'helpvar isPending' => {
    'lastUpdated' => '1252550740',
    'message' => 'Un condicional que indica si la Foto aún no ha sido aprobada. Los usuarios que pueden editar la Foto aún pueden examinarlas antes de que sea aprobada.'
  },
  'helpvar keyword' => {
    'lastUpdated' => '1252550751',
    'message' => 'La palabra clave'
  },
  'helpvar keywords' => {
    'lastUpdated' => '1252550765',
    'message' => 'Un ciclo que itera sobre las palabras clave asociadas con la Foto.'
  },
  'helpvar lastFile_thumbnailUrl' => {
    'lastUpdated' => '1272375903',
    'message' => 'El URL de la imagen miniatura de la última imagen del Album.'
  },
  'helpvar lastFile_title' => {
    'lastUpdated' => '1272375911',
    'message' => 'El título de la última imagen del Album.'
  },
  'helpvar lastFile_url' => {
    'lastUpdated' => '1272375920',
    'message' => 'El URL de la última imagen del Album.'
  },
  'helpvar nextFile_thumbnailUrl' => {
    'lastUpdated' => '1272376006',
    'message' => 'El URL de la imagen miniatura para la siguiente imagen del Album. Si no hay siguiente imagen, su valor será indefinido.'
  },
  'helpvar nextFile_title' => {
    'lastUpdated' => '1272376029',
    'message' => 'El título de la siguiente imagen del Album. Si no hay siguiente imagen, su valor será indefinido.'
  },
  'helpvar nextFile_url' => {
    'lastUpdated' => '1272376085',
    'message' => 'El URL de la siguiente imagen del Album. Si no hay siguiente imagen, su valor será indefinido.'
  },
  'helpvar numberOfComments' => {
    'lastUpdated' => '1252550795',
    'message' => 'El número total de comentarios sobre la Foto.'
  },
  'helpvar ownerAlias' => {
    'lastUpdated' => '1276810460',
    'message' => 'El alias del usuario que incluyó la foto, por omisión es el nombre del usuario.'
  },
  'helpvar ownerId' => {
    'lastUpdated' => '1276810477',
    'message' => 'El Id del usuario que incluyó esta foto.'
  },
  'helpvar ownerProfileUrl' => {
    'lastUpdated' => '1276810489',
    'message' => 'El URL al perfil del usuario que incluyó esta foto.'
  },
  'helpvar ownerUsername' => {
    'lastUpdated' => '1252550835',
    'message' => 'El nombre de usuario del usuario que incorporó la Foto.'
  },
  'helpvar previousFile_thumbnailUrl' => {
    'lastUpdated' => '1272375999',
    'message' => 'El URL de la imagen miniatura para la imagen anterior del Album. Si no hay imagen anterior, su valor será indefinido.'
  },
  'helpvar previousFile_title' => {
    'lastUpdated' => '1272376046',
    'message' => 'El título de la imagen anterior del Album. Si no hay imagen anterior, su valor será indefinido.'
  },
  'helpvar previousFile_url' => {
    'lastUpdated' => '1272376072',
    'message' => 'El URL de la imagen anterior del Album. Si no hay imagen anterior, su valor será indefinido.'
  },
  'helpvar resolutions_' => {
    'lastUpdated' => '1252550887',
    'message' => 'El URL directo a la foto con una resolución conocida, e.g. "resolutions_800"'
  },
  'helpvar resolutions_loop' => {
    'lastUpdated' => '1252550919',
    'message' => 'Las resoluciones disponibles para descarga que tiene esta Foto.'
  },
  'helpvar resolutions_loop resolution' => {
    'lastUpdated' => '1252551163',
    'message' => 'La resolución de la Foto.'
  },
  'helpvar resolutions_loop url_download' => {
    'lastUpdated' => '1252551190',
    'message' => 'El URL de la resolución a descargar.'
  },
  'helpvar synopsis_textonly' => {
    'lastUpdated' => '1252551217',
    'message' => 'El campo Resumen con todo el HTML eliminado.'
  },
  'helpvar thumbnailUrl' => {
    'lastUpdated' => '1252551257',
    'message' => 'El URL a la miniatura de esta Foto.'
  },
  'helpvar url_addArchive' => {
    'lastUpdated' => '1252551290',
    'message' => 'El URL para agregar un archivo al Album contenedor.'
  },
  'helpvar url_album' => {
    'lastUpdated' => '1252551302',
    'message' => 'La URL del Album que contiene este archivo'
  },
  'helpvar url_delete' => {
    'lastUpdated' => '1215796673',
    'message' => 'La URL para eliminar esta foto.'
  },
  'helpvar url_demote' => {
    'lastUpdated' => '1252551338',
    'message' => 'El URL para reducir el rango de la Foto.'
  },
  'helpvar url_edit' => {
    'lastUpdated' => '1215796689',
    'message' => 'La URL para editar est&aacute; foto.'
  },
  'helpvar url_gallery' => {
    'lastUpdated' => '1252551359',
    'message' => 'El URL de la Galería que contiene la Foto.'
  },
  'helpvar url_listFilesForOwner' => {
    'lastUpdated' => '1252551422',
    'message' => 'El URL con la lista de Archivos y Albums creados por el propietario de esta Foto.'
  },
  'helpvar url_makeShortcut' => {
    'lastUpdated' => '1252551461',
    'message' => 'El URL para preparar un atajo a esta Foto.'
  },
  'helpvar url_promote' => {
    'lastUpdated' => '1252551653',
    'message' => 'El URL para subir el rango de la Foto.'
  },
  'helpvar url_searchKeyword' => {
    'lastUpdated' => '1252551734',
    'message' => 'El URL hacia la página de búsqueda de la Galería.'
  },
  'helpvar url_searchKeywordUser' => {
    'lastUpdated' => '1252551769',
    'message' => 'El URL a la página de búsqueda de la Galería. Limita la búsqueda a Fotos de este usuario.'
  },
  'helpvar url_slideshow' => {
    'lastUpdated' => '1252551994',
    'message' => 'El URL a la vista Slideshow del Album que contiene esta Foto.'
  },
  'helpvar url_thumbnails' => {
    'lastUpdated' => '1252552036',
    'message' => 'El URL a la vista en miniaturas del Album que contiene esta Foto.'
  },
  'helpvar url_yes' => {
    'lastUpdated' => '1252552060',
    'message' => 'Confirme que desea eliminar esta Foto.'
  },
  'hide' => {
    'lastUpdated' => '1252552072',
    'message' => 'Esconder'
  },
  'more details' => {
    'lastUpdated' => '1252552085',
    'message' => 'Más detalles'
  },
  'save message' => {
    'lastUpdated' => '1252552109',
    'message' => 'La Foto ha sido enviada para aprobación.'
  },
  'template assetName' => {
    'lastUpdated' => '1252552118',
    'message' => 'Foto'
  },
  'template comment add title' => {
    'lastUpdated' => '1252552126',
    'message' => 'Agregar comentario'
  },
  'template comment creationDate' => {
    'lastUpdated' => '1252552136',
    'message' => 'Emitido el'
  },
  'template comment delete confirm' => {
    'lastUpdated' => '1252552148',
    'message' => '¿Está seguro que quiere eliminar este comentario?'
  },
  'template comment edit comment' => {
    'lastUpdated' => '1252552156',
    'message' => 'Editar comentario'
  },
  'template comment edit title' => {
    'lastUpdated' => '1252552320',
    'message' => 'Editar comentario'
  },
  'template comments title' => {
    'lastUpdated' => '1252552327',
    'message' => 'Comentarios'
  },
  'template creationDate' => {
    'lastUpdated' => '1252552381',
    'message' => 'Incorporada el'
  },
  'template delete albums' => {
    'lastUpdated' => '1252552396',
    'message' => 'La Foto está en los Albumes:'
  },
  'template delete message' => {
    'lastUpdated' => '1252552407',
    'message' => '¿Esta seguro que quiere eliminar esto?'
  },
  'template error happened' => {
    'lastUpdated' => '1252552422',
    'message' => 'Hubo un error mientras se procesaba su solicitud.'
  },
  'template fileUrl' => {
    'lastUpdated' => '1252552433',
    'message' => 'Ver la imagen a tamaño completo'
  },
  'template filesForUser' => {
    'lastUpdated' => '1276810499',
    'message' => 'Más fotos'
  },
  'template friendsOnly label' => {
    'lastUpdated' => '1252552439',
    'message' => 'Privacidad'
  },
  'template friendsOnly no' => {
    'lastUpdated' => '1252552447',
    'message' => 'Pública'
  },
  'template friendsOnly yes' => {
    'lastUpdated' => '1252552456',
    'message' => 'Amigos Solamente'
  },
  'template keywords' => {
    'lastUpdated' => '1252552462',
    'message' => 'Etiquetas'
  },
  'template location' => {
    'lastUpdated' => '1252552466',
    'message' => 'Ubicación'
  },
  'template makeShortcut album' => {
    'lastUpdated' => '1252552472',
    'message' => 'Album'
  },
  'template makeShortcut file' => {
    'lastUpdated' => '1252552479',
    'message' => 'Archivo'
  },
  'template makeShortcut title' => {
    'lastUpdated' => '1252552494',
    'message' => 'Publicación múltiple'
  },
  'template url_album' => {
    'lastUpdated' => '1252552498',
    'message' => 'Regresar al Album'
  },
  'template url_delete' => {
    'lastUpdated' => '1252552504',
    'message' => 'Eliminar Foto'
  },
  'template url_deleteComment' => {
    'lastUpdated' => '1252552510',
    'message' => 'Eliminar'
  },
  'template url_edit' => {
    'lastUpdated' => '1252552514',
    'message' => 'Editar Foto'
  },
  'template url_makeShortcut' => {
    'lastUpdated' => '1252552524',
    'message' => 'Publicación Múltiple'
  },
  'template view available resolutions' => {
    'lastUpdated' => '1252552534',
    'message' => 'Resoluciones disponibles'
  },
  'template view details' => {
    'lastUpdated' => '1252552540',
    'message' => 'Detalles'
  },
  'template view title' => {
    'lastUpdated' => '1215796336',
    'message' => 'Detalles de la Foto'
  },
  'template views' => {
    'lastUpdated' => '1215796321',
    'message' => 'Visitas'
  }
}
;

1;
